@@ -50,22 +50,40 @@ class TP_Importer(Excel_Importer):
         # "right_avod": 55,
         "premium_est_start": 55,
         "premium_est_end": 56,
-        "premium_est_price_tier": 57,
+        # "premium_est_price_tier": 57, # gelöscht am 30.03.2022
+        "premium_est_price_srp_sd": 52,
+        "premium_est_price_srp_hd": 53,
+        "premium_est_price_srp_uhd": 54,
         "premium_vod_start": 64,
         "premium_vod_end": 65,
-        "premium_vod_price_tier": 66,
+        # "premium_vod_price_tier": 66, # gelöscht am 30.03.2022
+        "premium_vod_price_srp_sd": 61,
+        "premium_vod_price_srp_hd": 62,
+        "premium_vod_price_srp_uhd": 63,
         "holdback_est_start": 67,
         "holdback_est_end": 68,
         "holdback_tvod_start": 69,
         "holdback_tvod_end": 70,
         "change_reason": 79,
         "pf_status_itunes": 81,
-        "pf_status_amazon": 105,
-        "pf_status_google": 97,
-        "pf_status_microsoft": 88,
+        "pf_status_chili": 83,
         "pf_status_videoload": 84,
-        "pf_status_sony": 86,
+        "pf_status_sony": 86, # wird nicht mehr benötigt
+        "pf_status_kino_on_demand": 87,
+        "pf_status_microsoft": 88,
+        "pf_status_vodafone": 90,
+        "pf_status_hollystar": 91,
+        "pf_status_magenta_at": 94,
+        "pf_status_upc_ch": 95,
+        "pf_status_rakuten": 96,
+        "pf_status_google": 97,
+        "pf_status_videociety": 98,
         "pf_status_ondemand": 99,
+        "pf_status_sky_tvod": 100,
+        "pf_status_sky_buy_and_keep": 101,
+        "pf_status_teleclub": 103,
+        "pf_status_videobuster": 104,
+        "pf_status_amazon": 105,
         "studio": 108,
         "vendor_id": 118,
         "vendor_id_itunes": 120,
@@ -130,6 +148,7 @@ class TP_Importer(Excel_Importer):
         "marketing_commitment_sky": 33,
         "marketing_commitment_videoload": 34,
         "pf_specific_id_sky": 121,
+        "so_number": 35,
     }
 
     def __init__(self, valid_statuses=("ok", "change", "new")):
